summaryrefslogtreecommitdiffstats
path: root/qt/qextscintilla.h
diff options
context:
space:
mode:
authorTimothy Pearson <kb9vqf@pearsoncomputing.net>2011-12-19 11:42:29 -0600
committerTimothy Pearson <kb9vqf@pearsoncomputing.net>2011-12-19 11:42:29 -0600
commit1aef904f94a86fecbc71888bc94a790ff36f0403 (patch)
treefd0070eb9a4dc25fc63b889d55f5c6198a324282 /qt/qextscintilla.h
parentc03d5480ab0242a8e6b03b466d90d32d39303e71 (diff)
downloadtqscintilla-1aef904f94a86fecbc71888bc94a790ff36f0403.tar.gz
tqscintilla-1aef904f94a86fecbc71888bc94a790ff36f0403.zip
Remove additional unneeded tq method conversions
Diffstat (limited to 'qt/qextscintilla.h')
-rw-r--r--qt/qextscintilla.h4
1 files changed, 2 insertions, 2 deletions
diff --git a/qt/qextscintilla.h b/qt/qextscintilla.h
index c34c88d..331ebad 100644
--- a/qt/qextscintilla.h
+++ b/qt/qextscintilla.h
@@ -920,10 +920,10 @@ public slots:
//! If any lines are currently folded then they are all unfolded.
//! Otherwise all lines are folded. This has the same effect as
//! clicking in the fold margin with the shift and control keys
//! pressed. If \a tqchildren is not set (the default) then only the top
//! level fold points are affected, otherwise the state of all fold
//! points are changed.
- virtual void foldAll(bool tqchildren = FALSE);
+ virtual void foldAll(bool children = FALSE);
//! If the line \a line is folded then it is unfolded. Otherwise it is
//! folded. This has the same effect as clicking in the fold margin.
@@ -920,10 +920,10 @@ public slots:
//! Otherwise all lines are folded. This has the same effect as
//! clicking in the fold margin with the shift and control keys
- //! pressed. If \a tqchildren is not set (the default) then only the top
+ //! pressed. If \a children is not set (the default) then only the top
//! level fold points are affected, otherwise the state of all fold
//! points are changed.